@@ -26,8 +26,8 @@
 
 import pwem
 
-
-_logo = ""
+__version__ = '3.0.7'
+_logo = "icon.gif"
 _references = []
 
 
